@@ -4,7 +4,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 my $self;
 
@@ -47,9 +47,9 @@ sub validate_data{
 	&&($self->{minConfidence}>=0&&$self->{minConfidence}<=100))
 		or die("Error: \$self->{minConfidence} invalid value!\n");
 	($self->{itemsKeyDescription})
-		or die("Error: \$self->{itemsKeyDescription} are not defined!\n");
+		or die("Error: \$self->{itemsKeyDescription} is not defined!\n");
 	($self->{itemsKeyTransactions})
-		or die("Error: \$self->{itemsKeyTransactions} are not defined!\n");
+		or die("Error: \$self->{itemsKeyTransactions} is not defined!\n");
 }
 
 sub generate_rules{
@@ -126,21 +126,20 @@ for(my$subsetSize=0;$subsetSize<$#itemsetCandidate;$subsetSize++){
 	for(my$item=1;$item<=$#subsetLeft;$item++){
 		@transactionsAssociation = grep $_ ~~ @transactionsAssociation,@{$self->{itemsKeyTransactions}{$subsetLeft[$item]}};
 	}
-	my $supportAssociation = scalar(@transactionsAssociation);
-	if($supportAssociation == 0){
+	my $supportAssociationLeft = scalar(@transactionsAssociation);
+	if($supportAssociationLeft == 0){
 		next;
 	}
-	my $supportLastAssociation = $supportAssociation;
 	for(my$item=0;$item<=$#subsetRight;$item++){
 		@transactionsAssociation = grep $_ ~~ @transactionsAssociation,@{$self->{itemsKeyTransactions}{$subsetRight[$item]}};
 	}
-	$supportAssociation = scalar(@transactionsAssociation);
-	if($supportAssociation == 0){
+	my $supportAssociationRight = scalar(@transactionsAssociation);
+	if($supportAssociationRight == 0){
 		next;
 	}
-	my $support = sprintf("%.2f",(($supportAssociation/$self->{totalTransactions})*100));
+	my $support = sprintf("%.2f",(($supportAssociationRight/$self->{totalTransactions})*100));
 	if($support >= $self->{minSupport}){
-		my $confidence = sprintf("%.2f",(($supportAssociation/$supportLastAssociation)*100));
+		my $confidence = sprintf("%.2f",(($supportAssociationRight/$supportAssociationLeft)*100));
 		if($confidence >= $self->{minConfidence}){
 			$support =~ s/\./,/;
 			$confidence =~ s/\./,/;
@@ -249,7 +248,7 @@ sub file{
 
 sub excel{
 	require Win32::OLE;
-	my($page,$range,$chart);
+	my($sheet,$range,$chart);
 	if($self->{messages}){
 		print "\nExporting to excel ...";
 	}
@@ -258,55 +257,53 @@ sub excel{
 		$self->{workbook} = $self->{excel}->Workbooks->Add;
 	}
 	$self->{workbook}->Worksheets->Add;
-	$page = $self->{workbook}->Worksheets(1);
-	$page->{Name} = "Itemset Size $self->{itemsetSize}";
-	$page->Range("A1:C1")->{Value} = ["Rule","Support %","Confidence %"];
+	$sheet = $self->{workbook}->Worksheets(1);
+	$sheet->{Name} = "Itemset Size $self->{itemsetSize}";
+	$sheet->Range("A1:C1")->{Value} = ["Rule","Support %","Confidence %"];
 	my $i = 1;
 	foreach my$rule(sort{$a<=>$b}keys(%{$self->{associationRules}})){
 		$i++;
-		$page->Range("A$i:C$i")->{Value} = ["R$rule",@{$self->{associationRules}{$rule}{"R$rule"}{rule}}[1],@{$self->{associationRules}{$rule}{"R$rule"}{rule}}[2]];
+		$sheet->Range("A$i:C$i")->{Value} = ["R$rule",@{$self->{associationRules}{$rule}{"R$rule"}{rule}}[1],@{$self->{associationRules}{$rule}{"R$rule"}{rule}}[2]];
 	}
 	my $j = $i + 1;
 	foreach my$rule(sort{$a<=>$b}keys(%{$self->{associationRules}})){
 		$j++;
-		$page->Range("A$j")->{Value} = "Rule R$rule: @{$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[0]";
+		$sheet->Range("A$j")->{Value} = "Rule R$rule: @{$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[0]";
 		$j++;
-		$page->Range("A$j")->{Value} =  "Support: @{$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[1] %";
+		$sheet->Range("A$j")->{Value} =  "Support: @{$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[1] %";
 		$j++;
-		$page->Range("A$j")->{Value} = "Confidence: @{$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[2] %";
+		$sheet->Range("A$j")->{Value} = "Confidence: @{$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[2] %";
 		$j++;
-		$page->Range("A$j")->{Value} = "Items:";
+		$sheet->Range("A$j")->{Value} = "Items:";
 		foreach my$item(@{$self->{associationRules}{$rule}{"R$rule"}{items}}){
 			$j++;
-			$page->Range("A$j")->{Value} = "$item $self->{itemsKeyDescription}{$item}";
+			$sheet->Range("A$j")->{Value} = "$item $self->{itemsKeyDescription}{$item}";
 		}
 		$j++;
 	}
 	$j++;
-	$page->Range("A$j")->{Value} = "Frequent itemset: { @{$self->{frequentItemset}} }";
+	$sheet->Range("A$j")->{Value} = "Frequent itemset: { @{$self->{frequentItemset}} }";
 	$j++;
-	$page->Range("A$j")->{Value} = "Items:";
+	$sheet->Range("A$j")->{Value} = "Items:";
 	foreach my$item(@{$self->{frequentItemset}}){
 		$j++;
-		$page->Range("A$j")->{Value} = "$item $self->{itemsKeyDescription}{$item}";
+		$sheet->Range("A$j")->{Value} = "$item $self->{itemsKeyDescription}{$item}";
 	}
-	$page->ListObjects->Add(1,$page->Range("A1:C$i"),1);
+	$sheet->ListObjects->Add(1,$sheet->Range("A1:C$i"),1);
 	$chart = $self->{excel}->Charts->Add;
 	$chart->{ChartType} = 51;
-	$chart->SetSourceData($page->Range("A1:C$i"),2);
-	$chart->Location(2,$page->{Name});
-	$page->ChartObjects(1)->{Top} = 10;
-	$page->ChartObjects(1)->{Left} = 350;
+	$chart->SetSourceData($sheet->Range("A1:C$i"),2);
+	$chart->Location(2,$sheet->{Name});
+	$sheet->ChartObjects(1)->{Top} = 10;
+	$sheet->ChartObjects(1)->{Left} = 350;
 	$self->{workbook}->{Saved} = 1;
 	$self->{excel}->{Visible} = 1;
 	$chart = 0;
-	$page = 0;
+	$sheet = 0;
 }
 
 return 1;
 __END__
-# Below is stub documentation for your module. You'd better edit it!
-
 =head1 NAME
 
 Data::Mining::Apriori - Perl extension for implement the data mining algorithm apriori.
@@ -317,113 +314,106 @@ Data::Mining::Apriori - Perl extension for implement the data mining algorithm a
 	use warnings;
 	use Data::Mining::Apriori;
 
-	#  TRANSACTION   CEREAL   MILK    BREAD
-	#         1101        1      1        0
-	#         1102        1      0        1
-	#         1103        1      1        1
-	#         1104        1      1        1
-	#         1105        0      1        1
-	#         1106        1      1        1
-	#         1107        1      1        1
-	#         1108        1      0        1
-	#         1109        1      1        1
-	#         1110        1      1        1
+	# TRANSACTION 103:CEREAL 101:MILK 102:BREAD
+	#        1101          1        1         0
+	#        1102          1        0         1
+	#        1103          1        1         1
+	#        1104          1        1         1
+	#        1105          0        1         1
+	#        1106          1        1         1
+	#        1107          1        1         1
+	#        1108          1        0         1
+	#        1109          1        1         1
+	#        1110          1        1         1
 
 	my $apriori = new Data::Mining::Apriori; 
 	 
-	$apriori->{totalTransactions}=10;
-	# The total number of transactions
+	$apriori->{totalTransactions}=10; # The total number of transactions
 
-	$apriori->{minSupport}=1.55;
-	# The minimum support
+	$apriori->{minSupport}=1.55; # The minimum support
 
-	$apriori->{minConfidence}=1.55;
-	# The minimum confidence
+	$apriori->{minConfidence}=1.55; # The minimum confidence
 
-	$apriori->{output}=1;
-	# The output type {1:export to file, 2:export to excel}(optional)
+	$apriori->{output}=1; # The output type {1:export to file, 2:export to excel}(optional)
 
-	$apriori->{messages}=1;
-	# A value boolean {1:true, 0:false} to display the messages(optional)
+	$apriori->{messages}=1; # One boolean {1:true, 0:false} to display the messages(optional)
 
-	$apriori->{itemsKeyDescription}{101}='MILK'; 
-	# Hash table to add items by key and description
+	$apriori->{itemsKeyDescription}{'101'}='MILK'; # Hash table to add items by key and description
 	$apriori->{itemsKeyDescription}{102}='BREAD';
-	$apriori->{itemsKeyDescription}{103}='CEREAL';
+	$apriori->{itemsKeyDescription}{'103'}='CEREAL';
 
-	@{$apriori->{itemsKeyTransactions}{101}}=(1101,1103,1104,1105,1106,1107,1109,1110); 
-	# Reference to array, to add the transactions of each item per key
-	@{$apriori->{itemsKeyTransactions}{102}}=(1102,1103,1104,1105,1106,1107,1108,1109,1110);
-	@{$apriori->{itemsKeyTransactions}{103}}=(1101,1102,1103,1104,1106,1107,1108,1109,1110);
+	@{$apriori->{itemsKeyTransactions}{'101'}}=('1101',1103,'1104',1105,'1106',1107,'1109',1110); # Reference to array, to add the transactions of each item per key
+	@{$apriori->{itemsKeyTransactions}{102}}=('1102',1103,'1104',1105,'1106',1107,1108,'1109',1110);
+	@{$apriori->{itemsKeyTransactions}{'103'}}=('1101',1102,1103,'1104','1106',1107,1108,'1109',1110);
 
-	$apriori->generate_rules; 
-	# Generate association rules to no longer meet the minimum support and confidence
+	$apriori->generate_rules; # Generate association rules to no longer meet the minimum support and confidence
 	# or
-	# $apriori->association_rules_itemset_size(3);
-	# Generate rules from a set of items size
+	# $apriori->association_rules_itemset_size(3); # Generate rules from a set of items size
 
-	print "\n@{$apriori->{frequentItemset}}\n"; 
-	# Show frequent items
+	print "\n@{$apriori->{frequentItemset}}\n"; # Show frequent items
 
 	# or from a database
 
-	#CREATE TABLE dimension_product(
-	#	product_key INTEGER NOT NULL PRIMARY KEY,
-	#	product_alternate_key INTEGER NOT NULL,
-	#	product_name TEXT NOT NULL,
-	#	price REAL NOT NULL
-	# // ...
-	#);
-	#INSERT INTO dimension_product VALUES(1,101,'MILK',10.00);
-	#INSERT INTO dimension_product VALUES(2,102,'BREAD',10.00);
-	#INSERT INTO dimension_product VALUES(3,103,'CEREAL',10.00);
+	# CREATE TABLE dimension_product(
+	# 	product_key INTEGER NOT NULL PRIMARY KEY,
+	# 	product_alternate_key INTEGER NOT NULL,
+	# 	product_name TEXT NOT NULL,
+	# 	price REAL NOT NULL
+	#  // ...
+	# );
+	#
+	# INSERT INTO dimension_product VALUES(1,101,'MILK',10.00);
+	# INSERT INTO dimension_product VALUES(2,102,'BREAD',10.00);
+	# INSERT INTO dimension_product VALUES(3,103,'CEREAL',10.00);
 	# 
 	# // ...
 	# 
-	#CREATE TABLE fact_sales(
-	#	sales_order_number INTEGER NOT NULL,
-	#	sales_order_line_number INTEGER NOT NULL,
-	#	product_key INTEGER NOT NULL,
-	#	quantity INTEGER NOT NULL,
-	# // ...
-	#	PRIMARY KEY(sales_order_number, sales_order_line_number),
-	#	FOREIGN KEY(product_key) REFERENCES dimension_product(product_key)
-	#);
-	#INSERT INTO fact_sales VALUES(1101,1,3,1);
-	#INSERT INTO fact_sales VALUES(1101,2,1,1);
-	#INSERT INTO fact_sales VALUES(1102,1,3,1);
-	#INSERT INTO fact_sales VALUES(1102,2,2,1);
-	#INSERT INTO fact_sales VALUES(1103,1,1,1);
-	#INSERT INTO fact_sales VALUES(1103,2,2,1);
-	#INSERT INTO fact_sales VALUES(1103,3,3,1);
-	#INSERT INTO fact_sales VALUES(1104,1,1,1);
-	#INSERT INTO fact_sales VALUES(1104,2,2,1);
-	#INSERT INTO fact_sales VALUES(1104,3,3,1);
-	#INSERT INTO fact_sales VALUES(1105,1,1,1);
-	#INSERT INTO fact_sales VALUES(1105,2,2,1);
-	#INSERT INTO fact_sales VALUES(1106,1,1,1);
-	#INSERT INTO fact_sales VALUES(1106,2,2,1);
-	#INSERT INTO fact_sales VALUES(1106,3,3,1);
-	#INSERT INTO fact_sales VALUES(1107,1,1,1);
-	#INSERT INTO fact_sales VALUES(1107,2,2,1);
-	#INSERT INTO fact_sales VALUES(1107,3,3,1);
-	#INSERT INTO fact_sales VALUES(1108,1,3,1);
-	#INSERT INTO fact_sales VALUES(1108,2,2,1);
-	#INSERT INTO fact_sales VALUES(1109,1,1,1);
-	#INSERT INTO fact_sales VALUES(1109,2,2,1);
-	#INSERT INTO fact_sales VALUES(1109,3,3,1);
-	#INSERT INTO fact_sales VALUES(1110,1,1,1);
-	#INSERT INTO fact_sales VALUES(1110,2,2,1);
-	#INSERT INTO fact_sales VALUES(1110,3,3,1);
+	# CREATE TABLE fact_sales(
+	# 	sales_order_number INTEGER NOT NULL,
+	# 	sales_order_line_number INTEGER NOT NULL,
+	# 	product_key INTEGER NOT NULL,
+	# 	quantity INTEGER NOT NULL,
+	#  // ...
+	# 	PRIMARY KEY(sales_order_number, sales_order_line_number),
+	# 	FOREIGN KEY(product_key) REFERENCES dimension_product(product_key)
+	# );
+	#
+	# INSERT INTO fact_sales VALUES(1101,1,3,1);
+	# INSERT INTO fact_sales VALUES(1101,2,1,1);
+	# INSERT INTO fact_sales VALUES(1102,1,3,1);
+	# INSERT INTO fact_sales VALUES(1102,2,2,1);
+	# INSERT INTO fact_sales VALUES(1103,1,1,1);
+	# INSERT INTO fact_sales VALUES(1103,2,2,1);
+	# INSERT INTO fact_sales VALUES(1103,3,3,1);
+	# INSERT INTO fact_sales VALUES(1104,1,1,1);
+	# INSERT INTO fact_sales VALUES(1104,2,2,1);
+	# INSERT INTO fact_sales VALUES(1104,3,3,1);
+	# INSERT INTO fact_sales VALUES(1105,1,1,1);
+	# INSERT INTO fact_sales VALUES(1105,2,2,1);
+	# INSERT INTO fact_sales VALUES(1106,1,1,1);
+	# INSERT INTO fact_sales VALUES(1106,2,2,1);
+	# INSERT INTO fact_sales VALUES(1106,3,3,1);
+	# INSERT INTO fact_sales VALUES(1107,1,1,1);
+	# INSERT INTO fact_sales VALUES(1107,2,2,1);
+	# INSERT INTO fact_sales VALUES(1107,3,3,1);
+	# INSERT INTO fact_sales VALUES(1108,1,3,1);
+	# INSERT INTO fact_sales VALUES(1108,2,2,1);
+	# INSERT INTO fact_sales VALUES(1109,1,1,1);
+	# INSERT INTO fact_sales VALUES(1109,2,2,1);
+	# INSERT INTO fact_sales VALUES(1109,3,3,1);
+	# INSERT INTO fact_sales VALUES(1110,1,1,1);
+	# INSERT INTO fact_sales VALUES(1110,2,2,1);
+	# INSERT INTO fact_sales VALUES(1110,3,3,1);
 
 	use DBD::SQLite;
 	use Data::Mining::Apriori;
 
 	my $db = DBI->connect('dbi:SQLite:dbname=DW.db','','');
 
-	my $sql = q{
+	my $sql = q~
 	SELECT COUNT(DISTINCT(sales_order_number)) FROM fact_sales
-	};
+	/* WHERE ... */
+	~;
 
 	my $query = $db->prepare($sql);
 	$query->execute;
